__title__ = "cv-py"
# __version__ = get_version() # TODO
__version__ = "0.1.5"  # placeholder for dynamic version
__compatible__ = "0.1.2"
__release__ = False
__download_url__ = "https://github.com/usnistgov/cord19-cdcs-nist/releases"
